/** options for each client instance */
interface ClientOptions extends RequestInit {
    /** set the common root URL for all API requests */
    baseUrl?: string;
}
interface BaseParams {
    path?: Record<string, unknown>;
    query?: Record<string, unknown>;
}
type TruncatedResponse = Omit<Response, 'arrayBuffer' | 'blob' | 'body' | 'clone' | 'formData' | 'json' | 'text'>;
/** Infer request/response from content type */
type Unwrap<T> = T extends {
    content: {
        'application/json': {
            schema: any;
        };
    };
} ? T['content']['application/json']['schema'] : T extends {
    content: {
        'application/json': any;
    };
} ? T['content']['application/json'] : T extends {
    content: {
        '*/*': {
            schema: any;
        };
    };
} ? T['content']['*/*']['schema'] : T extends {
    content: {
        '*/*': any;
    };
} ? T['content']['*/*'] : T;
export default function createClient<T>(defaultOptions?: ClientOptions): {
    /** Call a GET endpoint */
    get<U extends keyof T, M extends keyof T[U]>(url: T[U] extends {
        get: any;
    } ? U : never, options: (T[U] extends {
        parameters: any;
    } ? {
        params: T[U]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U][M] extends {
        parameters: any;
    } ? {
        params: T[U][M]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U][M] extends {
        requestBody: any;
    } ? {
        body: Unwrap<T[U][M]["requestBody"]>;
    } : {
        body?: undefined;
    }) & Omit<RequestInit, "body">): Promise<{
        data: T[T[U] extends {
            get: any;
        } ? U : never][keyof T[T[U] extends {
            get: any;
        } ? U : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U] extends {
            get: any;
        } ? U : never][keyof T[T[U] extends {
            get: any;
        } ? U : never]]["responses"] extends infer T_1 ? T_1 extends T[T[U] extends {
            get: any;
        } ? U : never][keyof T[T[U] extends {
            get: any;
        } ? U : never]]["responses"] ? T_1 extends {
            200: any;
        } ? T_1[200] : T_1 extends {
            201: any;
        } ? T_1[201] : T_1 extends {
            202: any;
        } ? T_1[202] : T_1 extends {
            default: any;
        } ? T_1["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[T[U] extends {
            get: any;
        } ? U : never][keyof T[T[U] extends {
            get: any;
        } ? U : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U] extends {
            get: any;
        } ? U : never][keyof T[T[U] extends {
            get: any;
        } ? U : never]]["responses"] extends infer T_2 ? T_2 extends T[T[U] extends {
            get: any;
        } ? U : never][keyof T[T[U] extends {
            get: any;
        } ? U : never]]["responses"] ? T_2 extends {
            500: any;
        } ? T_2[500] : T_2 extends {
            404: any;
        } ? T_2[404] : T_2 extends {
            402: any;
        } ? T_2[402] : T_2 extends {
            401: any;
        } ? T_2[401] : T_2 extends {
            400: any;
        } ? T_2[400] : T_2 extends {
            422: any;
        } ? T_2[422] : T_2 extends {
            418: any;
        } ? T_2[418] : T_2 extends {
            417: any;
        } ? T_2[417] : T_2 extends {
            416: any;
        } ? T_2[416] : T_2 extends {
            415: any;
        } ? T_2[415] : T_2 extends {
            414: any;
        } ? T_2[414] : T_2 extends {
            413: any;
        } ? T_2[413] : T_2 extends {
            412: any;
        } ? T_2[412] : T_2 extends {
            411: any;
        } ? T_2[411] : T_2 extends {
            410: any;
        } ? T_2[410] : T_2 extends {
            409: any;
        } ? T_2[409] : T_2 extends {
            408: any;
        } ? T_2[408] : T_2 extends {
            407: any;
        } ? T_2[407] : T_2 extends {
            406: any;
        } ? T_2[406] : T_2 extends {
            405: any;
        } ? T_2[405] : T_2 extends {
            default: any;
        } ? T_2["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a PUT endpoint */
    put<U_1 extends keyof T, M_1 extends keyof T[U_1]>(url: T[U_1] extends {
        put: any;
    } ? U_1 : never, options: (T[U_1] extends {
        parameters: any;
    } ? {
        params: T[U_1]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_1][M_1] extends {
        parameters: any;
    } ? {
        params: T[U_1][M_1]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_1][M_1] extends {
        requestBody: any;
    } ? {
        body: Unwrap<T[U_1][M_1]["requestBody"]>;
    } : {
        body?: undefined;
    }) & Omit<RequestInit, "body">): Promise<{
        data: T[T[U_1] extends {
            put: any;
        } ? U_1 : never][keyof T[T[U_1] extends {
            put: any;
        } ? U_1 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_1] extends {
            put: any;
        } ? U_1 : never][keyof T[T[U_1] extends {
            put: any;
        } ? U_1 : never]]["responses"] extends infer T_3 ? T_3 extends T[T[U_1] extends {
            put: any;
        } ? U_1 : never][keyof T[T[U_1] extends {
            put: any;
        } ? U_1 : never]]["responses"] ? T_3 extends {
            200: any;
        } ? T_3[200] : T_3 extends {
            201: any;
        } ? T_3[201] : T_3 extends {
            202: any;
        } ? T_3[202] : T_3 extends {
            default: any;
        } ? T_3["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[T[U_1] extends {
            put: any;
        } ? U_1 : never][keyof T[T[U_1] extends {
            put: any;
        } ? U_1 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_1] extends {
            put: any;
        } ? U_1 : never][keyof T[T[U_1] extends {
            put: any;
        } ? U_1 : never]]["responses"] extends infer T_4 ? T_4 extends T[T[U_1] extends {
            put: any;
        } ? U_1 : never][keyof T[T[U_1] extends {
            put: any;
        } ? U_1 : never]]["responses"] ? T_4 extends {
            500: any;
        } ? T_4[500] : T_4 extends {
            404: any;
        } ? T_4[404] : T_4 extends {
            402: any;
        } ? T_4[402] : T_4 extends {
            401: any;
        } ? T_4[401] : T_4 extends {
            400: any;
        } ? T_4[400] : T_4 extends {
            422: any;
        } ? T_4[422] : T_4 extends {
            418: any;
        } ? T_4[418] : T_4 extends {
            417: any;
        } ? T_4[417] : T_4 extends {
            416: any;
        } ? T_4[416] : T_4 extends {
            415: any;
        } ? T_4[415] : T_4 extends {
            414: any;
        } ? T_4[414] : T_4 extends {
            413: any;
        } ? T_4[413] : T_4 extends {
            412: any;
        } ? T_4[412] : T_4 extends {
            411: any;
        } ? T_4[411] : T_4 extends {
            410: any;
        } ? T_4[410] : T_4 extends {
            409: any;
        } ? T_4[409] : T_4 extends {
            408: any;
        } ? T_4[408] : T_4 extends {
            407: any;
        } ? T_4[407] : T_4 extends {
            406: any;
        } ? T_4[406] : T_4 extends {
            405: any;
        } ? T_4[405] : T_4 extends {
            default: any;
        } ? T_4["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a POST endpoint */
    post<U_2 extends keyof T, M_2 extends keyof T[U_2]>(url: T[U_2] extends {
        post: any;
    } ? U_2 : never, options: (T[U_2] extends {
        parameters: any;
    } ? {
        params: T[U_2]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_2][M_2] extends {
        parameters: any;
    } ? {
        params: T[U_2][M_2]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_2][M_2] extends {
        requestBody: any;
    } ? {
        body: Unwrap<T[U_2][M_2]["requestBody"]>;
    } : {
        body?: undefined;
    }) & Omit<RequestInit, "body">): Promise<{
        data: T[T[U_2] extends {
            post: any;
        } ? U_2 : never][keyof T[T[U_2] extends {
            post: any;
        } ? U_2 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_2] extends {
            post: any;
        } ? U_2 : never][keyof T[T[U_2] extends {
            post: any;
        } ? U_2 : never]]["responses"] extends infer T_5 ? T_5 extends T[T[U_2] extends {
            post: any;
        } ? U_2 : never][keyof T[T[U_2] extends {
            post: any;
        } ? U_2 : never]]["responses"] ? T_5 extends {
            200: any;
        } ? T_5[200] : T_5 extends {
            201: any;
        } ? T_5[201] : T_5 extends {
            202: any;
        } ? T_5[202] : T_5 extends {
            default: any;
        } ? T_5["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[T[U_2] extends {
            post: any;
        } ? U_2 : never][keyof T[T[U_2] extends {
            post: any;
        } ? U_2 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_2] extends {
            post: any;
        } ? U_2 : never][keyof T[T[U_2] extends {
            post: any;
        } ? U_2 : never]]["responses"] extends infer T_6 ? T_6 extends T[T[U_2] extends {
            post: any;
        } ? U_2 : never][keyof T[T[U_2] extends {
            post: any;
        } ? U_2 : never]]["responses"] ? T_6 extends {
            500: any;
        } ? T_6[500] : T_6 extends {
            404: any;
        } ? T_6[404] : T_6 extends {
            402: any;
        } ? T_6[402] : T_6 extends {
            401: any;
        } ? T_6[401] : T_6 extends {
            400: any;
        } ? T_6[400] : T_6 extends {
            422: any;
        } ? T_6[422] : T_6 extends {
            418: any;
        } ? T_6[418] : T_6 extends {
            417: any;
        } ? T_6[417] : T_6 extends {
            416: any;
        } ? T_6[416] : T_6 extends {
            415: any;
        } ? T_6[415] : T_6 extends {
            414: any;
        } ? T_6[414] : T_6 extends {
            413: any;
        } ? T_6[413] : T_6 extends {
            412: any;
        } ? T_6[412] : T_6 extends {
            411: any;
        } ? T_6[411] : T_6 extends {
            410: any;
        } ? T_6[410] : T_6 extends {
            409: any;
        } ? T_6[409] : T_6 extends {
            408: any;
        } ? T_6[408] : T_6 extends {
            407: any;
        } ? T_6[407] : T_6 extends {
            406: any;
        } ? T_6[406] : T_6 extends {
            405: any;
        } ? T_6[405] : T_6 extends {
            default: any;
        } ? T_6["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a DELETE endpoint */
    del<U_3 extends keyof T, M_3 extends keyof T[U_3]>(url: T[U_3] extends {
        delete: any;
    } ? U_3 : never, options: (T[U_3] extends {
        parameters: any;
    } ? {
        params: T[U_3]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_3][M_3] extends {
        parameters: any;
    } ? {
        params: T[U_3][M_3]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_3][M_3] extends {
        requestBody: any;
    } ? {
        body: Unwrap<T[U_3][M_3]["requestBody"]>;
    } : {
        body?: undefined;
    }) & Omit<RequestInit, "body">): Promise<{
        data: T[T[U_3] extends {
            delete: any;
        } ? U_3 : never][keyof T[T[U_3] extends {
            delete: any;
        } ? U_3 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_3] extends {
            delete: any;
        } ? U_3 : never][keyof T[T[U_3] extends {
            delete: any;
        } ? U_3 : never]]["responses"] extends infer T_7 ? T_7 extends T[T[U_3] extends {
            delete: any;
        } ? U_3 : never][keyof T[T[U_3] extends {
            delete: any;
        } ? U_3 : never]]["responses"] ? T_7 extends {
            200: any;
        } ? T_7[200] : T_7 extends {
            201: any;
        } ? T_7[201] : T_7 extends {
            202: any;
        } ? T_7[202] : T_7 extends {
            default: any;
        } ? T_7["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[T[U_3] extends {
            delete: any;
        } ? U_3 : never][keyof T[T[U_3] extends {
            delete: any;
        } ? U_3 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_3] extends {
            delete: any;
        } ? U_3 : never][keyof T[T[U_3] extends {
            delete: any;
        } ? U_3 : never]]["responses"] extends infer T_8 ? T_8 extends T[T[U_3] extends {
            delete: any;
        } ? U_3 : never][keyof T[T[U_3] extends {
            delete: any;
        } ? U_3 : never]]["responses"] ? T_8 extends {
            500: any;
        } ? T_8[500] : T_8 extends {
            404: any;
        } ? T_8[404] : T_8 extends {
            402: any;
        } ? T_8[402] : T_8 extends {
            401: any;
        } ? T_8[401] : T_8 extends {
            400: any;
        } ? T_8[400] : T_8 extends {
            422: any;
        } ? T_8[422] : T_8 extends {
            418: any;
        } ? T_8[418] : T_8 extends {
            417: any;
        } ? T_8[417] : T_8 extends {
            416: any;
        } ? T_8[416] : T_8 extends {
            415: any;
        } ? T_8[415] : T_8 extends {
            414: any;
        } ? T_8[414] : T_8 extends {
            413: any;
        } ? T_8[413] : T_8 extends {
            412: any;
        } ? T_8[412] : T_8 extends {
            411: any;
        } ? T_8[411] : T_8 extends {
            410: any;
        } ? T_8[410] : T_8 extends {
            409: any;
        } ? T_8[409] : T_8 extends {
            408: any;
        } ? T_8[408] : T_8 extends {
            407: any;
        } ? T_8[407] : T_8 extends {
            406: any;
        } ? T_8[406] : T_8 extends {
            405: any;
        } ? T_8[405] : T_8 extends {
            default: any;
        } ? T_8["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a OPTIONS endpoint */
    options<U_4 extends keyof T, M_4 extends keyof T[U_4]>(url: T[U_4] extends {
        options: any;
    } ? U_4 : never, options: (T[U_4] extends {
        parameters: any;
    } ? {
        params: T[U_4]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_4][M_4] extends {
        parameters: any;
    } ? {
        params: T[U_4][M_4]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_4][M_4] extends {
        requestBody: any;
    } ? {
        body: Unwrap<T[U_4][M_4]["requestBody"]>;
    } : {
        body?: undefined;
    }) & Omit<RequestInit, "body">): Promise<{
        data: T[T[U_4] extends {
            options: any;
        } ? U_4 : never][keyof T[T[U_4] extends {
            options: any;
        } ? U_4 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_4] extends {
            options: any;
        } ? U_4 : never][keyof T[T[U_4] extends {
            options: any;
        } ? U_4 : never]]["responses"] extends infer T_9 ? T_9 extends T[T[U_4] extends {
            options: any;
        } ? U_4 : never][keyof T[T[U_4] extends {
            options: any;
        } ? U_4 : never]]["responses"] ? T_9 extends {
            200: any;
        } ? T_9[200] : T_9 extends {
            201: any;
        } ? T_9[201] : T_9 extends {
            202: any;
        } ? T_9[202] : T_9 extends {
            default: any;
        } ? T_9["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[T[U_4] extends {
            options: any;
        } ? U_4 : never][keyof T[T[U_4] extends {
            options: any;
        } ? U_4 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_4] extends {
            options: any;
        } ? U_4 : never][keyof T[T[U_4] extends {
            options: any;
        } ? U_4 : never]]["responses"] extends infer T_10 ? T_10 extends T[T[U_4] extends {
            options: any;
        } ? U_4 : never][keyof T[T[U_4] extends {
            options: any;
        } ? U_4 : never]]["responses"] ? T_10 extends {
            500: any;
        } ? T_10[500] : T_10 extends {
            404: any;
        } ? T_10[404] : T_10 extends {
            402: any;
        } ? T_10[402] : T_10 extends {
            401: any;
        } ? T_10[401] : T_10 extends {
            400: any;
        } ? T_10[400] : T_10 extends {
            422: any;
        } ? T_10[422] : T_10 extends {
            418: any;
        } ? T_10[418] : T_10 extends {
            417: any;
        } ? T_10[417] : T_10 extends {
            416: any;
        } ? T_10[416] : T_10 extends {
            415: any;
        } ? T_10[415] : T_10 extends {
            414: any;
        } ? T_10[414] : T_10 extends {
            413: any;
        } ? T_10[413] : T_10 extends {
            412: any;
        } ? T_10[412] : T_10 extends {
            411: any;
        } ? T_10[411] : T_10 extends {
            410: any;
        } ? T_10[410] : T_10 extends {
            409: any;
        } ? T_10[409] : T_10 extends {
            408: any;
        } ? T_10[408] : T_10 extends {
            407: any;
        } ? T_10[407] : T_10 extends {
            406: any;
        } ? T_10[406] : T_10 extends {
            405: any;
        } ? T_10[405] : T_10 extends {
            default: any;
        } ? T_10["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a HEAD endpoint */
    head<U_5 extends keyof T, M_5 extends keyof T[U_5]>(url: T[U_5] extends {
        head: any;
    } ? U_5 : never, options: (T[U_5] extends {
        parameters: any;
    } ? {
        params: T[U_5]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_5][M_5] extends {
        parameters: any;
    } ? {
        params: T[U_5][M_5]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_5][M_5] extends {
        requestBody: any;
    } ? {
        body: Unwrap<T[U_5][M_5]["requestBody"]>;
    } : {
        body?: undefined;
    }) & Omit<RequestInit, "body">): Promise<{
        data: T[T[U_5] extends {
            head: any;
        } ? U_5 : never][keyof T[T[U_5] extends {
            head: any;
        } ? U_5 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_5] extends {
            head: any;
        } ? U_5 : never][keyof T[T[U_5] extends {
            head: any;
        } ? U_5 : never]]["responses"] extends infer T_11 ? T_11 extends T[T[U_5] extends {
            head: any;
        } ? U_5 : never][keyof T[T[U_5] extends {
            head: any;
        } ? U_5 : never]]["responses"] ? T_11 extends {
            200: any;
        } ? T_11[200] : T_11 extends {
            201: any;
        } ? T_11[201] : T_11 extends {
            202: any;
        } ? T_11[202] : T_11 extends {
            default: any;
        } ? T_11["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[T[U_5] extends {
            head: any;
        } ? U_5 : never][keyof T[T[U_5] extends {
            head: any;
        } ? U_5 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_5] extends {
            head: any;
        } ? U_5 : never][keyof T[T[U_5] extends {
            head: any;
        } ? U_5 : never]]["responses"] extends infer T_12 ? T_12 extends T[T[U_5] extends {
            head: any;
        } ? U_5 : never][keyof T[T[U_5] extends {
            head: any;
        } ? U_5 : never]]["responses"] ? T_12 extends {
            500: any;
        } ? T_12[500] : T_12 extends {
            404: any;
        } ? T_12[404] : T_12 extends {
            402: any;
        } ? T_12[402] : T_12 extends {
            401: any;
        } ? T_12[401] : T_12 extends {
            400: any;
        } ? T_12[400] : T_12 extends {
            422: any;
        } ? T_12[422] : T_12 extends {
            418: any;
        } ? T_12[418] : T_12 extends {
            417: any;
        } ? T_12[417] : T_12 extends {
            416: any;
        } ? T_12[416] : T_12 extends {
            415: any;
        } ? T_12[415] : T_12 extends {
            414: any;
        } ? T_12[414] : T_12 extends {
            413: any;
        } ? T_12[413] : T_12 extends {
            412: any;
        } ? T_12[412] : T_12 extends {
            411: any;
        } ? T_12[411] : T_12 extends {
            410: any;
        } ? T_12[410] : T_12 extends {
            409: any;
        } ? T_12[409] : T_12 extends {
            408: any;
        } ? T_12[408] : T_12 extends {
            407: any;
        } ? T_12[407] : T_12 extends {
            406: any;
        } ? T_12[406] : T_12 extends {
            405: any;
        } ? T_12[405] : T_12 extends {
            default: any;
        } ? T_12["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a PATCH endpoint */
    patch<U_6 extends keyof T, M_6 extends keyof T[U_6]>(url: T[U_6] extends {
        patch: any;
    } ? U_6 : never, options: (T[U_6] extends {
        parameters: any;
    } ? {
        params: T[U_6]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_6][M_6] extends {
        parameters: any;
    } ? {
        params: T[U_6][M_6]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_6][M_6] extends {
        requestBody: any;
    } ? {
        body: Unwrap<T[U_6][M_6]["requestBody"]>;
    } : {
        body?: undefined;
    }) & Omit<RequestInit, "body">): Promise<{
        data: T[T[U_6] extends {
            patch: any;
        } ? U_6 : never][keyof T[T[U_6] extends {
            patch: any;
        } ? U_6 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_6] extends {
            patch: any;
        } ? U_6 : never][keyof T[T[U_6] extends {
            patch: any;
        } ? U_6 : never]]["responses"] extends infer T_13 ? T_13 extends T[T[U_6] extends {
            patch: any;
        } ? U_6 : never][keyof T[T[U_6] extends {
            patch: any;
        } ? U_6 : never]]["responses"] ? T_13 extends {
            200: any;
        } ? T_13[200] : T_13 extends {
            201: any;
        } ? T_13[201] : T_13 extends {
            202: any;
        } ? T_13[202] : T_13 extends {
            default: any;
        } ? T_13["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[T[U_6] extends {
            patch: any;
        } ? U_6 : never][keyof T[T[U_6] extends {
            patch: any;
        } ? U_6 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_6] extends {
            patch: any;
        } ? U_6 : never][keyof T[T[U_6] extends {
            patch: any;
        } ? U_6 : never]]["responses"] extends infer T_14 ? T_14 extends T[T[U_6] extends {
            patch: any;
        } ? U_6 : never][keyof T[T[U_6] extends {
            patch: any;
        } ? U_6 : never]]["responses"] ? T_14 extends {
            500: any;
        } ? T_14[500] : T_14 extends {
            404: any;
        } ? T_14[404] : T_14 extends {
            402: any;
        } ? T_14[402] : T_14 extends {
            401: any;
        } ? T_14[401] : T_14 extends {
            400: any;
        } ? T_14[400] : T_14 extends {
            422: any;
        } ? T_14[422] : T_14 extends {
            418: any;
        } ? T_14[418] : T_14 extends {
            417: any;
        } ? T_14[417] : T_14 extends {
            416: any;
        } ? T_14[416] : T_14 extends {
            415: any;
        } ? T_14[415] : T_14 extends {
            414: any;
        } ? T_14[414] : T_14 extends {
            413: any;
        } ? T_14[413] : T_14 extends {
            412: any;
        } ? T_14[412] : T_14 extends {
            411: any;
        } ? T_14[411] : T_14 extends {
            410: any;
        } ? T_14[410] : T_14 extends {
            409: any;
        } ? T_14[409] : T_14 extends {
            408: any;
        } ? T_14[408] : T_14 extends {
            407: any;
        } ? T_14[407] : T_14 extends {
            406: any;
        } ? T_14[406] : T_14 extends {
            405: any;
        } ? T_14[405] : T_14 extends {
            default: any;
        } ? T_14["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
    /** Call a TRACE endpoint */
    trace<U_7 extends keyof T, M_7 extends keyof T[U_7]>(url: T[U_7] extends {
        trace: any;
    } ? U_7 : never, options: (T[U_7] extends {
        parameters: any;
    } ? {
        params: T[U_7]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_7][M_7] extends {
        parameters: any;
    } ? {
        params: T[U_7][M_7]["parameters"];
    } : {
        params?: BaseParams | undefined;
    }) & (T[U_7][M_7] extends {
        requestBody: any;
    } ? {
        body: Unwrap<T[U_7][M_7]["requestBody"]>;
    } : {
        body?: undefined;
    }) & Omit<RequestInit, "body">): Promise<{
        data: T[T[U_7] extends {
            trace: any;
        } ? U_7 : never][keyof T[T[U_7] extends {
            trace: any;
        } ? U_7 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_7] extends {
            trace: any;
        } ? U_7 : never][keyof T[T[U_7] extends {
            trace: any;
        } ? U_7 : never]]["responses"] extends infer T_15 ? T_15 extends T[T[U_7] extends {
            trace: any;
        } ? U_7 : never][keyof T[T[U_7] extends {
            trace: any;
        } ? U_7 : never]]["responses"] ? T_15 extends {
            200: any;
        } ? T_15[200] : T_15 extends {
            201: any;
        } ? T_15[201] : T_15 extends {
            202: any;
        } ? T_15[202] : T_15 extends {
            default: any;
        } ? T_15["default"] : unknown : never : never> : unknown;
        error?: undefined;
        response: TruncatedResponse;
    } | {
        data?: undefined;
        error: T[T[U_7] extends {
            trace: any;
        } ? U_7 : never][keyof T[T[U_7] extends {
            trace: any;
        } ? U_7 : never]] extends {
            responses: any;
        } ? Unwrap<T[T[U_7] extends {
            trace: any;
        } ? U_7 : never][keyof T[T[U_7] extends {
            trace: any;
        } ? U_7 : never]]["responses"] extends infer T_16 ? T_16 extends T[T[U_7] extends {
            trace: any;
        } ? U_7 : never][keyof T[T[U_7] extends {
            trace: any;
        } ? U_7 : never]]["responses"] ? T_16 extends {
            500: any;
        } ? T_16[500] : T_16 extends {
            404: any;
        } ? T_16[404] : T_16 extends {
            402: any;
        } ? T_16[402] : T_16 extends {
            401: any;
        } ? T_16[401] : T_16 extends {
            400: any;
        } ? T_16[400] : T_16 extends {
            422: any;
        } ? T_16[422] : T_16 extends {
            418: any;
        } ? T_16[418] : T_16 extends {
            417: any;
        } ? T_16[417] : T_16 extends {
            416: any;
        } ? T_16[416] : T_16 extends {
            415: any;
        } ? T_16[415] : T_16 extends {
            414: any;
        } ? T_16[414] : T_16 extends {
            413: any;
        } ? T_16[413] : T_16 extends {
            412: any;
        } ? T_16[412] : T_16 extends {
            411: any;
        } ? T_16[411] : T_16 extends {
            410: any;
        } ? T_16[410] : T_16 extends {
            409: any;
        } ? T_16[409] : T_16 extends {
            408: any;
        } ? T_16[408] : T_16 extends {
            407: any;
        } ? T_16[407] : T_16 extends {
            406: any;
        } ? T_16[406] : T_16 extends {
            405: any;
        } ? T_16[405] : T_16 extends {
            default: any;
        } ? T_16["default"] : unknown : never : never> : unknown;
        response: TruncatedResponse;
    }>;
};
export {};
